@@ -3,23 +3,23 @@ Color points from the size of the sphere radius."""
 from vedo import *
 from vedo.pyplot import histogram
 
-settings.useDepthPeeling = True
+settings.use_depth_peeling = True
 
 plt = Plotter()
 
-msh = Mesh(dataurl+"cow.vtk").alpha(0.3)
+msh = Mesh(dataurl+"cow.vtk").c("cyan7")
 
 pts1, pts2, vals, cols = [], [], [], []
 
-for i in range(0, msh.N(), 10):
+for i in range(0, msh.npoints, 10):
     p = msh.points(i)
-    pts = msh.closestPoint(p, N=12)  # find the N closest points to p
-    sph = fitSphere(pts)           # find the fitting sphere
+    pts = msh.closest_point(p, n=12)  # find the n-closest points to p
+    sph = fit_sphere(pts)             # find the fitting sphere
     if sph is None:
         continue
 
     value = sph.radius * 10
-    color = colorMap(value, "jet", 0, 1)  # map value to a RGB color
+    color = color_map(value, "jet", 0, 1)  # map value to a RGB color
     n = versor(p - sph.center)  # unit vector from sphere center to p
     vals.append(value)
     cols.append(color)
@@ -29,7 +29,7 @@ for i in range(0, msh.N(), 10):
 plt += msh
 plt += Points(pts1, c=cols)
 plt += Lines(pts1, pts2, c="black")
-plt += histogram(vals, xtitle='radius', xlim=[0,2]).pos(-1,0.5,-1)
+plt += histogram(vals, xtitle='radius', xlim=[0,2]).as2d(pos="bottom-left")
 plt += __doc__
 
 plt.show().close()
