@@ -10,7 +10,7 @@ import scipy.optimize as opt
 
 print(__doc__)
 
-settings.useDepthPeeling = True
+settings.use_depth_peeling = True
 
 plt = Plotter(shape=[1, 3], interactive=0, axes=1)
 
@@ -48,13 +48,13 @@ class Morpher:
         self.params = pars
 
         #calculate chi2
-        d2sum, n = 0.0, self.source.N()
+        d2sum, n = 0.0, self.source.npoints
         srcpts = self.source.points()
         rng = range(0, n, int(n / self.subsample))
         for i in rng:
             p1 = srcpts[i]
             p2 = self.transform(p1)
-            tp = self.target.closestPoint(p2)
+            tp = self.target.closest_point(p2)
             d2sum += mag2(p2 - tp)
         d2sum /= len(rng)
 
@@ -89,7 +89,7 @@ class Morpher:
         res = opt.minimize(self._func, x0,
                            bounds=bnds, method=self.method, tol=self.tolerance)
         # recalc for all pts:
-        self.subsample = self.source.N()
+        self.subsample = self.source.npoints
         self._func(res["x"])
         print("\nFinal fit score", res["fun"])
         self.fitResult = res
@@ -118,7 +118,7 @@ class Morpher:
         hair = Arrows(arrs, s=0.3, alpha=0.5, c='jet')
 
         zero = Point(pos, c="black")
-        x1, x2, y1, y2, z1, z2 = self.target.polydata().GetBounds()
+        x1, x2, y1, y2, z1, z2 = self.target.bounds()
         tpos = [x1, y2, z1]
         text1 = Text3D("source vs target", tpos, s=sz / 10, c="dg")
         text2 = Text3D("morphed vs target", tpos, s=sz / 10, c="dg")
