@@ -2,7 +2,7 @@
 from vedo import Line, settings, np
 from vedo.pyplot import histogram
 
-settings.defaultFont = 11
+settings.default_font = 11
 
 data = np.random.rand(10000)
 weights = np.ones_like(data) * np.sin(12*data)**2 + 1/2
@@ -24,8 +24,8 @@ x = np.linspace(0,1, 200)
 y = 200*np.sin(12*x)**2 + 100
 fig += Line(x, y, c='red5', lw=3)
 
-fig.addLabel('my function', marker='-', mc='red5')
-fig.addLegend(pos=[0.7,1.33], alpha=0.2)
+fig.add_label('my function', marker='-', mc='red5')
+fig.add_legend(pos=[0.7,1.33], alpha=0.2)
 
 fig.show(size=(1000,700), bg='black', zoom='tight').close()
 
