@@ -9,7 +9,7 @@ import numpy as np
 
 K_COULOMB = 8987551787.3681764  # N*m^2/C^2
 plt = None  # so that it can be also used without visualization
-settings.allowInteraction = True
+settings.allow_interaction = True
 
 
 class ParticleSim:
@@ -88,7 +88,7 @@ class Particle:
         self.negligible = negligible
         self.color = color
         if plt:
-            self.vsphere = Sphere(pos, r=radius, c=color).addTrail(lw=0.1, n=100, alpha=0.2)
+            self.vsphere = Sphere(pos, r=radius, c=color).add_trail(lw=0.1, n=100, alpha=0.2)
             plt.add(self.vsphere, render=False)  # Sphere representing the particle
 
 
