@@ -4,16 +4,16 @@ Press ESC to quit"""
 # https://www.youtube.com/watch?v=MtG9cueB548
 from vedo import *
 
-settings.allowInteraction = True
+settings.allow_interaction = True
 
 # Load the solution:
 x1, y1, z1,  x2, y2, z2 = np.load(download(dataurl+'3Dpen.npy'))
 p1, p2 = np.c_[x1,y1,z1], np.c_[x2,y2,z2]
 
-ball1 = Sphere(c="green5", r=0.1, pos=p1[0]).addTrail(n=10).addShadow('z', -3)
-ball2 = Sphere(c="blue5",  r=0.1, pos=p2[0]).addTrail(n=10).addShadow('z', -3)
-ball1.trail.addShadow('z', -3) # make trails project a shadow too
-ball2.trail.addShadow('z', -3)
+ball1 = Sphere(c="green5", r=0.1, pos=p1[0]).add_trail(n=10).add_shadow('z', -3)
+ball2 = Sphere(c="blue5",  r=0.1, pos=p2[0]).add_trail(n=10).add_shadow('z', -3)
+ball1.trail.add_shadow('z', -3) # make trails project a shadow too
+ball2.trail.add_shadow('z', -3)
 
 rod1 = Line([0,0,0], ball1, lw=4)
 rod2 = Line(ball1, ball2, lw=4)
