@@ -40,7 +40,7 @@ def d_dt(psi):  # find Psi(t+dt)-Psi(t) /dt with 4th order Runge-Kutta method
     k4 = f(psi + dt * k3)
     return (k1 + 2 * k2 + 2 * k3 + k4) / 6
 
-settings.allowInteraction = True
+settings.allow_interaction = True
 
 plt = Plotter(interactive=False)
 bck = Picture(dataurl+"images/schrod.png").alpha(.3).scale(.0256).pos([0,-5,-.1])
