@@ -18,18 +18,23 @@ import argparse
 import glob
 import os
 import sys
+
 import numpy as np
-import vtk
+
+try:
+    import vedo.vtkclasses as vtk
+except ImportError:
+    import vtkmodules.all as vtk
 
 import vedo
 from vedo.utils import humansort
-from vedo.utils import isSequence
-from vedo.utils import printInfo
+from vedo.utils import is_sequence
+from vedo.utils import print_info
 from vedo import __version__
 from vedo import io
 from vedo import load
 from vedo import settings
-from vedo.colors import getColor, printc
+from vedo.colors import get_color, printc
 from vedo.mesh import Mesh
 from vedo.picture import Picture
 from vedo.plotter import Plotter
@@ -87,7 +92,7 @@ def get_parser():
     pr.add_argument("-w", "--wireframe",            help="use wireframe representation", action="store_true")
     pr.add_argument("-p", "--point-size", type=float, help="specify point size", default=-1, metavar='')
     pr.add_argument("-l", "--showedges",            help="show a thin line on mesh edges", action="store_true")
-    pr.add_argument("-k", "--lighting", type=str,   help="metallic, plastic, shiny or glossy", default='default', metavar='')
+    pr.add_argument("-k", "--lighting", type=str,   help="metallic, plastic, shiny, glossy or off", default='default', metavar='')
     pr.add_argument("-K", "--flat",                 help="use flat shading", action="store_true")
     pr.add_argument("-t", "--texture-file",         help="texture image file", default='', metavar='')
     pr.add_argument("-x", "--axes-type", type=int,  help="specify axes type [0-14]", default=1, metavar='')
@@ -127,12 +132,12 @@ def system_info():
         try:
             A = load(file)
             if isinstance(A, np.ndarray):
-                printInfo(A)
-            elif isSequence(A):
+                print_info(A)
+            elif is_sequence(A):
                 for a in A:
-                    printInfo(a)
+                    print_info(a)
             else:
-                printInfo(A)
+                print_info(A)
         except:
             vedo.logger.error(f"Could not load {file}, skip.")
 
@@ -140,6 +145,7 @@ def system_info():
     printc("vedo version      :", __version__, invert=1, end="   ")
     printc("https://vedo.embl.es", underline=1, italic=1)
     printc("vtk version       :", vtk.vtkVersion().GetVTKVersion())
+    printc("numpy version     :", np.__version__)
     printc("python version    :", sys.version.replace("\n", ""))
     printc("python interpreter:", sys.executable)
     printc("vedo installation :", vedo.installdir)
@@ -152,6 +158,7 @@ def system_info():
 
     try:
         from screeninfo import get_monitors
+
         for m in get_monitors():
             pr = "         "
             if m.is_primary:
@@ -162,21 +169,25 @@ def system_info():
 
     try:
         import k3d
+
         printc("k3d version       :", k3d.__version__, bold=0, dim=1)
     except ModuleNotFoundError:
         pass
     try:
         import ipyvtk_simple
+
         printc("ipyvtk version    :", ipyvtk_simple.__version__, bold=0, dim=1)
     except ModuleNotFoundError:
         pass
     try:
         import itkwidgets
+
         printc("itkwidgets version:", itkwidgets.__version__, bold=0, dim=1)
     except ModuleNotFoundError:
         pass
     try:
         import panel
+
         printc("panel version     :", panel.__version__, bold=0, dim=1)
     except ModuleNotFoundError:
         pass
@@ -187,7 +198,11 @@ def exe_run(args):
     expath = os.path.join(vedo.installdir, "examples", "**", "*.py")
     exfiles = list(glob.glob(expath, recursive=True))
     f2search = os.path.basename(args.run).lower()
-    matching = [s for s in exfiles if (f2search in os.path.basename(s).lower() and "__" not in s)]
+    matching = [
+        s
+        for s in exfiles
+        if (f2search in os.path.basename(s).lower() and "__" not in s)
+    ]
     matching = list(sorted(matching))
     nmat = len(matching)
     if nmat == 0:
@@ -202,7 +217,7 @@ def exe_run(args):
     if args.full_screen:  # -f option not to dump the full code but just the first line
         for mat in matching[:25]:
             printc(os.path.basename(mat).replace(".py", ""), c="y", italic=1, end=" ")
-            with open(mat, 'r') as fm:
+            with open(mat, 'r', encoding='UTF-8') as fm:
                 lline = ''.join(fm.readlines(60))
                 lline = lline.replace('\n',' ').replace('\'','').replace('\"','').replace('-','')
                 line = lline[:56] #cut
@@ -222,7 +237,7 @@ def exe_run(args):
         sys.exit(0)
 
     if not args.full_screen:  # -f option not to dump the full code
-        with open(matching[0], 'r') as fm:
+        with open(matching[0], "r", encoding="UTF-8") as fm:
             code = fm.read()
         code = "#" * 80 + "\n" + code + "\n" + "#" * 80
 
@@ -296,7 +311,7 @@ def exe_search(args):
         pattern = pattern.lower()
     if len(pattern) > 3:
         for ifile in exfiles:
-            with open(ifile, "r") as file:
+            with open(ifile, "r", encoding="UTF-8") as file:
                 fflag = True
                 for i, line in enumerate(file):
                     if args.no_camera_share:
@@ -342,7 +357,7 @@ def exe_search_vtk(args):
                 raise RuntimeError(f"Failed to download {dl_url}. {e.reason}")
         return path
 
-    def get_examples(d, vtk_class, lang, all_values=False, number=5):
+    def get_examples(d, vtk_class, lang):
         try:
             kv = d[vtk_class][lang].items()
         except KeyError as e:
@@ -362,10 +377,10 @@ def exe_search_vtk(args):
     # Force a new download if the time difference is > 10 minutes.
     if dt > 600:
         path = download_file(tmp_dir, xref_url, overwrite=True)
-    with open(path, 'r') as json_file:
+    with open(path, "r", encoding="UTF-8") as json_file:
         xref_dict = json.load(json_file)
 
-    total_number, examples = get_examples(xref_dict, vtk_class, language, all_values=all_values, number=number)
+    total_number, examples = get_examples(xref_dict, vtk_class, language)
     if examples:
         if total_number <= number or all_values:
             print(
@@ -385,16 +400,16 @@ def exe_search_vtk(args):
 #################################################################################################################
 def exe_eog(args):
     # print("EOG emulator")
-    settings.immediateRendering = False
-    settings.useParallelProjection = True
-    settings.enableDefaultMouseCallbacks = False
-    settings.enableDefaultKeyboardCallbacks = False
+    settings.immediate_rendering = False
+    settings.use_parallel_projection = True
+    settings.enable_default_mouse_callbacks = False
+    settings.enable_default_keyboard_callbacks = False
 
     if args.background == "":
         args.background = "white"
 
     if args.background_grad:
-        args.background_grad = getColor(args.background_grad)
+        args.background_grad = get_color(args.background_grad)
 
     files = []
     for s in sys.argv:
@@ -405,42 +420,42 @@ def exe_eog(args):
         files.append(s)
 
     def vfunc(event):
-        # print(event.keyPressed)
+        # print(event.keypress)
         for p in pics:
-            if event.keyPressed == "r":
+            if event.keypress == "r":
                 p.window(win).level(lev)
-            elif event.keyPressed == "Up":
+            elif event.keypress == "Up":
                 p.level(p.level() + 10)
-            elif event.keyPressed == "Down":
+            elif event.keypress == "Down":
                 p.level(p.level() - 10)
-            if event.keyPressed == "Right":
+            if event.keypress == "Right":
                 p.window(p.window() + 10)
-            elif event.keyPressed == "Down":
+            elif event.keypress == "Down":
                 p.window(p.window() - 10)
-            elif event.keyPressed == "m":
+            elif event.keypress == "m":
                 p.mirror()
-            elif event.keyPressed == "t":
+            elif event.keypress == "t":
                 p.rotate(90)
-            elif event.keyPressed == "f":
+            elif event.keypress == "f":
                 p.flip()
-            elif event.keyPressed == "b":
+            elif event.keypress == "b":
                 p.binarize()
-            elif event.keyPressed == "i":
+            elif event.keypress == "i":
                 p.invert()
-            elif event.keyPressed == "I":
-                plt.colorPicker(event.picked2d, verbose=True)
-            elif event.keyPressed == "k":
+            elif event.keypress == "I":
+                plt.color_picker(event.picked2d, verbose=True)
+            elif event.keypress == "k":
                 p.enhance()
-            elif event.keyPressed == "s":
+            elif event.keypress == "s":
                 p.smooth(sigma=1)
-            elif event.keyPressed == "S":
-                ahl = plt.hoverLegends[-1]
+            elif event.keypress == "S":
+                ahl = plt.hover_legends[-1]
                 plt.remove(ahl)
                 plt.screenshot()  # writer
                 printc("Picture saved as screenshot.png")
                 plt.add(ahl, render=False)
                 return
-            elif event.keyPressed == "h":
+            elif event.keypress == "h":
                 printc("---------------------------------------------")
                 printc("Press:")
                 printc("  up/down     to modify level (or drag mouse)")
@@ -480,16 +495,17 @@ def exe_eog(args):
     if n > 1:
 
         plt = Plotter(N=n, sharecam=True, bg=args.background, bg2=args.background_grad)
-        plt.addCallback("key press", vfunc)
+        plt.add_callback("key press", vfunc)
         for i in range(n):
             p = pics[i].pickable(True)
             pos = [-p.shape[0] / 2, -p.shape[1] / 2, 0]
             p.pos(pos)
-            plt.addHoverLegend(at=i, c="k8", bg="k2", alpha=0.4)
+            plt.add_hover_legend(at=i, c="k8", bg="k2", alpha=0.4)
             plt.show(p, axes=0, at=i, mode="image")
         plt.show(interactive=False)
-        plt.resetCamera(tight=0.05)
+        plt.reset_camera(tight=0.05)
         plt.interactor.Start()
+        if vedo.vtk_version == (9,2,2): plt.interactor.GetRenderWindow().SetDisplayId("_0_p_void")
 
     else:
 
@@ -502,12 +518,15 @@ def exe_eog(args):
             shape[0] = shape[0] / shape[1] * 1200
             shape[1] = 1200
 
-        plt = Plotter(title=files[0], size=shape, bg=args.background, bg2=args.background_grad)
-        plt.addCallback('key press', vfunc)
-        plt.addHoverLegend(c='k8', bg='k2', alpha=0.4)
-        plt.show(pic, mode='image',  interactive=False)
-        plt.resetCamera(tight=0.0)
+        plt = Plotter(
+            title=files[0], size=shape, bg=args.background, bg2=args.background_grad
+        )
+        plt.add_callback("key press", vfunc)
+        plt.add_hover_legend(c="k8", bg="k2", alpha=0.4)
+        plt.show(pic, mode="image", interactive=False)
+        plt.reset_camera(tight=0.0)
         plt.interactor.Start()
+        if vedo.vtk_version == (9,2,2): plt.interactor.GetRenderWindow().SetDisplayId("_0_p_void")
 
     plt.close()
 
@@ -533,7 +552,7 @@ def draw_scene(args):
         args.background = "white"
 
     if args.background_grad:
-        args.background_grad = getColor(args.background_grad)
+        args.background_grad = get_color(args.background_grad)
 
     if nfiles == 1 and args.files[0].endswith(".gif"):  ###can be improved
         frames = load(args.files[0])
@@ -551,18 +570,21 @@ def draw_scene(args):
             printc("Warning: option '-n' allows a maximum of 200 files", c=1)
             printc("         you are trying to load ", nfiles, " files.\n", c=1)
             N = 200
+        if N > 4:
+            settings.use_depth_peeling = False
+
         plt = Plotter(size=wsize, N=N, bg=args.background, bg2=args.background_grad)
-        settings.immediateRendering = False
+        settings.immediate_rendering = False
         plt.axes = args.axes_type
         for i in range(N):
-            plt.addHoverLegend(at=i)
+            plt.add_hover_legend(at=i)
         if args.axes_type in (4, 5):
             plt.axes = 0
     else:
         N = nfiles
         plt = Plotter(size=wsize, bg=args.background, bg2=args.background_grad)
         plt.axes = args.axes_type
-        plt.addHoverLegend()
+        plt.add_hover_legend()
 
     plt.sharecam = not args.no_camera_share
 
@@ -618,7 +640,7 @@ def draw_scene(args):
             vol,
             bg="white",
             bg2="lb",
-            useSlider3D=useSlider3D,
+            use_slider3d=useSlider3D,
             cmaps=[args.cmap, "Spectral_r", "hot_r", "bone_r", "gist_ncar_r"],
             alpha=args.alpha,
             axes=args.axes_type,
@@ -631,18 +653,16 @@ def draw_scene(args):
     elif args.edit:
         # print('edit mode for meshes and pointclouds')
         vedo.plotter_instance = None  # reset
-        settings.useParallelProjection = True
+        settings.use_parallel_projection = True
 
         try:
             m = Mesh(args.files[0], alpha=args.alpha / 2, c=args.color)
         except AttributeError:
-            vedo.logger.critical(
-                "In edit mode, input file must be a point cloud or polygonal mesh."
-            )
+            vedo.logger.critical("In edit mode, input file must be a point cloud or polygonal mesh.")
             return
 
         plt = applications.FreeHandCutPlotter(m, splined=True)
-        plt.addHoverLegend()
+        plt.add_hover_legend()
         if not args.background_grad:
             args.background_grad = None
         plt.start(axes=1, bg=args.background, bg2=args.background_grad)
@@ -715,6 +735,7 @@ def draw_scene(args):
 
         ds = 0
         actors = []
+
         for i in range(N):
             f = args.files[i]
 
@@ -727,8 +748,7 @@ def draw_scene(args):
             if isinstance(actor, (TetMesh, UGrid)):
                 actor = actor.tomesh().shrink(0.975).c(colb).alpha(args.alpha)
 
-            if isinstance(actor, Mesh):
-                actors.append(actor)
+            elif isinstance(actor, vedo.Points):
                 actor.c(colb).alpha(args.alpha).wireframe(wire).lighting(args.lighting)
                 if args.flat:
                     actor.flat()
@@ -739,11 +759,10 @@ def draw_scene(args):
                     actor.texture(args.texture_file)
 
                 if args.point_size > 0:
-                    try:
-                        actor.GetProperty().SetPointSize(args.point_size)
-                        actor.GetProperty().SetRepresentationToPoints()
-                    except AttributeError:
-                        pass
+                    actor.ps(args.point_size)
+
+                if args.cmap != "jet":
+                    actor.cmap(args.cmap)
 
                 if args.showedges:
                     try:
@@ -752,27 +771,26 @@ def draw_scene(args):
                         actor.GetProperty().SetRepresentationToSurface()
                     except AttributeError:
                         pass
-            else:
-                actors.append(actor)
+
+            actors.append(actor)
 
             if args.multirenderer_mode:
                 try:
-                    ds = actor.diagonalSize() * 3
+                    ds = actor.diagonal_size() * 3
                     plt.camera.SetClippingRange(0, ds)
                     plt.show(actor, at=i, interactive=False, zoom=args.zoom, mode=interactor_mode)
                     plt.actors = actors
                     # if args.no_camera_share: ## BUG
-                        # plt.resetCamera()
-                        # plt.renderers[i].ResetCameraClippingRange()
-                        # print([plt.camera])
+                    # plt.reset_camera()
+                    # plt.renderers[i].ResetCameraClippingRange()
+                    # print([plt.camera])
                 except AttributeError:
                     # wildcards in quotes make glob return actor as a list :(
-                    vedo.logger.error(
-                        "Please do not use wildcards within single or double quotes"
-                    )
+                    vedo.logger.error("Please do not use wildcards within single or double quotes")
 
         if args.multirenderer_mode:
             plt.interactor.Start()
+            if vedo.vtk_version == (9,2,2): plt.interactor.GetRenderWindow().SetDisplayId("_0_p_void")
 
         else:
 
@@ -796,6 +814,25 @@ def draw_scene(args):
         for a in acts:
             if hasattr(a, "c"):  # Picture doesnt have it
                 a.c(args.color)
+
+            if args.point_size > 0:
+                try:
+                    a.GetProperty().SetPointSize(args.point_size)
+                    a.GetProperty().SetRepresentationToPoints()
+                except AttributeError:
+                    pass
+
+            if args.cmap != "jet":
+                try:
+                    a.cmap(args.cmap)
+                except AttributeError:
+                    pass
+
+            try:
+                a.lighting(args.lighting)
+            except AttributeError:
+                pass
+
             a.alpha(args.alpha)
 
         plt = applications.Browser(acts, axes=1)
@@ -858,21 +895,21 @@ def exe_gui(args):
                 "plum",
                 "tomato",
             )
-            self.colorCB = Combobox(self, state="readonly", values=colvalues, width=10)
-            self.colorCB.current(0)
-            self.colorCB.place(x=100, y=98)
+            self.color_cb = Combobox(self, state="readonly", values=colvalues, width=10)
+            self.color_cb.current(0)
+            self.color_cb.place(x=100, y=98)
 
             # mode
             modvalues = ("surface", "surf. & edges", "wireframe", "point cloud")
-            self.surfmodeCB = Combobox(
+            self.surfmode_cb = Combobox(
                 self, state="readonly", values=modvalues, width=14
             )
-            self.surfmodeCB.current(0)
-            self.surfmodeCB.place(x=205, y=98)
+            self.surfmode_cb.current(0)
+            self.surfmode_cb.place(x=205, y=98)
 
             # alpha
             Label(self, text="Alpha:", bg="white").place(x=30, y=145)
-            self.alphaCB = Scale(
+            self.alpha_cb = Scale(
                 self,
                 from_=0,
                 to=1,
@@ -881,35 +918,48 @@ def exe_gui(args):
                 length=220,
                 orient="horizontal",
             )
-            self.alphaCB.set(1.0)
-            self.alphaCB.place(x=100, y=125)
+            self.alpha_cb.set(1.0)
+            self.alpha_cb.place(x=100, y=125)
 
             # lighting
             Label(self, text="Lighting:", bg="white").place(x=30, y=180)
-            lightvalues = ('default','metallic','plastic','shiny','glossy')
-            self.lightCB = Combobox(self, state="readonly", values=lightvalues, width=10)
-            self.lightCB.current(0)
-            self.lightCB.place(x=100, y=180)
+            lightvalues = ("default", "metallic", "plastic", "shiny", "glossy", "off")
+            self.light_cb = Combobox(
+                self, state="readonly", values=lightvalues, width=10
+            )
+            self.light_cb.current(0)
+            self.light_cb.place(x=100, y=180)
             # shading phong or flat
-            self.flatCB = Checkbutton(self, text="flat shading", var=self.flat, bg="white")
-            #self.flatCB.select()
-            self.flatCB.place(x=210, y=180)
+            self.flat_cb = Checkbutton(
+                self, text="flat shading", var=self.flat, bg="white"
+            )
+            # self.flat_cb.select()
+            self.flat_cb.place(x=210, y=180)
 
             # rendering arrangement
             Label(self, text="Arrange as:", bg="white").place(x=30, y=220)
-            schemevalues = ('superpose (default)','mesh browser', 'n sync-ed renderers')
-            self.schememodeCB = Combobox(self, state="readonly", values=schemevalues, width=20)
-            self.schememodeCB.current(0)
-            self.schememodeCB.place(x=160, y=220)
+            schemevalues = (
+                "superpose (default)",
+                "mesh browser",
+                "n sync-ed renderers",
+            )
+            self.schememode_cb = Combobox(
+                self, state="readonly", values=schemevalues, width=20
+            )
+            self.schememode_cb.current(0)
+            self.schememode_cb.place(x=160, y=220)
 
             # share cam
-            self.noshareCB = Checkbutton(self, text="independent cameras",
-                                         variable=self.noshare, bg="white")
-            self.noshareCB.place(x=160, y=245)
+            self.noshare_cb = Checkbutton(
+                self, text="independent cameras", variable=self.noshare, bg="white"
+            )
+            self.noshare_cb.place(x=160, y=245)
 
             ############volumes
             Frame(root, height=1, width=398, bg="grey").place(x=1, y=275)
-            Label(self, text="Volumes", fg="white", bg="blue", font=("Courier 11 bold")).place(x=20, y=280)
+            Label(
+                self, text="Volumes", fg="white", bg="blue", font=("Courier 11 bold")
+            ).place(x=20, y=280)
 
             # mode
             Label(self, text="Rendering mode:", bg="white").place(x=30, y=310)
@@ -921,20 +971,20 @@ def exe_gui(args):
                 "slicer2d",
                 "slicer3d",
             )
-            self.modeCB = Combobox(self, state="readonly", values=modevalues, width=20)
-            self.modeCB.current(0)
-            self.modeCB.place(x=160, y=310)
+            self.mode_cb = Combobox(self, state="readonly", values=modevalues, width=20)
+            self.mode_cb.current(0)
+            self.mode_cb.place(x=160, y=310)
 
             Label(self, text="Spacing factors:", bg="white").place(x=30, y=335)
-            self.xspacingCB = Entry(self, textvariable=self.xspacing, width=3)
+            self.xspacing_cb = Entry(self, textvariable=self.xspacing, width=3)
             self.xspacing.set("1.0")
-            self.xspacingCB.place(x=160, y=335)
-            self.yspacingCB = Entry(self, textvariable=self.yspacing, width=3)
+            self.xspacing_cb.place(x=160, y=335)
+            self.yspacing_cb = Entry(self, textvariable=self.yspacing, width=3)
             self.yspacing.set("1.0")
-            self.yspacingCB.place(x=210, y=335)
-            self.zspacingCB = Entry(self, textvariable=self.zspacing, width=3)
+            self.yspacing_cb.place(x=210, y=335)
+            self.zspacing_cb = Entry(self, textvariable=self.zspacing, width=3)
             self.zspacing.set("1.0")
-            self.zspacingCB.place(x=260, y=335)
+            self.zspacing_cb.place(x=260, y=335)
 
             ############## options
             Frame(root, height=1, width=398,bg="grey").place(x=1, y=370)
@@ -943,13 +993,14 @@ def exe_gui(args):
             # backgr color
             Label(self, text="Background color:", bg="white").place(x=30, y=405)
             bgcolvalues = ("white", "lightyellow", "azure", "blackboard", "black")
-            self.bgcolorCB = Combobox(self, state="readonly", values=bgcolvalues, width=9)
-            self.bgcolorCB.current(3)
-            self.bgcolorCB.place(x=160, y=405)
+            self.bgcolor_cb = Combobox(self, state="readonly", values=bgcolvalues, width=9)
+            self.bgcolor_cb.current(3)
+            self.bgcolor_cb.place(x=160, y=405)
             # backgr color gradient
-            self.backgroundGradCB = Checkbutton(self, text="gradient",
-                                                variable=self.background_grad, bg="white")
-            self.backgroundGradCB.place(x=255, y=405)
+            self.backgroundGrad_cb = Checkbutton(
+                self, text="gradient", variable=self.background_grad, bg="white"
+            )
+            self.backgroundGrad_cb.place(x=255, y=405)
 
             ################ render button
             Frame(root, height=1, width=398, bg="grey").place(x=1, y=437)
@@ -996,48 +1047,48 @@ def exe_gui(args):
         def _run(self):
 
             args.files = list(self.filenames)
-            if self.colorCB.get() == "by scalar":
+            if self.color_cb.get() == "by scalar":
                 args.color = None
             else:
-                if self.colorCB.get() == "red":
+                if self.color_cb.get() == "red":
                     args.color = "crimson"
-                elif self.colorCB.get() == "green":
+                elif self.color_cb.get() == "green":
                     args.color = "limegreen"
-                elif self.colorCB.get() == "blue":
+                elif self.color_cb.get() == "blue":
                     args.color = "darkcyan"
                 else:
-                    args.color = self.colorCB.get()
+                    args.color = self.color_cb.get()
 
-            args.alpha = self.alphaCB.get()
+            args.alpha = self.alpha_cb.get()
 
             args.wireframe = False
             args.showedges = False
             args.point_size = 0
-            if self.surfmodeCB.get() == "point cloud":
+            if self.surfmode_cb.get() == "point cloud":
                 args.point_size = 2
-            elif self.surfmodeCB.get() == "wireframe":
+            elif self.surfmode_cb.get() == "wireframe":
                 args.wireframe = True
-            elif self.surfmodeCB.get() == "surf. & edges":
+            elif self.surfmode_cb.get() == "surf. & edges":
                 args.showedges = True
             else:
                 pass  # normal surface mode
 
-            args.lighting = self.lightCB.get()
+            args.lighting = self.light_cb.get()
             args.flat = self.flat.get()
 
             args.no_camera_share = self.noshare.get()
-            args.background = self.bgcolorCB.get()
+            args.background = self.bgcolor_cb.get()
 
             args.background_grad = None
             if self.background_grad.get():
-                b = getColor(args.background)
+                b = get_color(args.background)
                 args.background_grad = (b[0] / 1.8, b[1] / 1.8, b[2] / 1.8)
 
             args.multirenderer_mode = False
             args.scrolling_mode = False
-            if self.schememodeCB.get() == "n sync-ed renderers":
+            if self.schememode_cb.get() == "n sync-ed renderers":
                 args.multirenderer_mode = True
-            elif self.schememodeCB.get() == "mesh browser":
+            elif self.schememode_cb.get() == "mesh browser":
                 args.scrolling_mode = True
 
             args.ray_cast_mode = False
@@ -1046,17 +1097,17 @@ def exe_gui(args):
             args.slicer2d = False
             args.lego = False
             args.mode = 0
-            if self.modeCB.get() == "composite":
+            if self.mode_cb.get() == "composite":
                 args.ray_cast_mode = True
                 args.mode = 0
-            elif self.modeCB.get() == "maximum proj":
+            elif self.mode_cb.get() == "maximum proj":
                 args.ray_cast_mode = True
                 args.mode = 1
-            elif self.modeCB.get() == "slicer3d":
+            elif self.mode_cb.get() == "slicer3d":
                 args.slicer3d = True
-            elif self.modeCB.get() == "slicer2d":
+            elif self.mode_cb.get() == "slicer2d":
                 args.slicer2d = True
-            elif self.modeCB.get() == "lego":
+            elif self.mode_cb.get() == "lego":
                 args.lego = True
 
             args.x_spacing = 1
