@@ -1,8 +1,15 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 import os
 import sys
 import time
+
 import numpy as np
-import vtk
+
+try:
+    import vedo.vtkclasses as vtk
+except ImportError:
+    import vtkmodules.all as vtk
 
 import vedo
 
@@ -14,21 +21,25 @@ Colors definitions and printing methods. <br>
 __all__ = [
     "printc",
     "printd",
-    "getColor",
-    "getColorName",
-    "colorMap",
-    "buildPalette",
-    "buildLUT",
+    "get_color",
+    "get_color_name",
+    "color_map",
+    "build_palette",
+    "build_lut",
+    "getColor", # deprecated will disappear
+    "colorMap", # deprecated
+    "buildLUT", # deprecated
 ]
 
 
 try:
     import matplotlib.cm as cm_mpl
     _has_matplotlib = True
+    cmaps = {}
 except ModuleNotFoundError:
     from vedo.cmaps import cmaps
     _has_matplotlib = False
-    # see below, this is dealt with in colorMap()
+    # see below, this is dealt with in color_map()
 
 #########################################################
 # handy global shortcuts for terminal printing
@@ -521,33 +532,33 @@ palettes = (
 
 
 emoji = {
-    "\bomb": "\U0001F4A5",
-    "\sparks": "\U00002728",
-    "\ethumbup": "\U0001F44d",
-    "\etarget": "\U0001F3af",
-    "\save": "\U0001F4be",
-    "\noentry": "\U000026d4",
-    "\video": "\U0001F4fd ",
-    "\lightning": "\U000026a1",
-    "\camera": "\U0001F4f8",
-    "\times": "\U0000274c",
-    "\world": "\U0001F30d",
-    "\erainbow": "\U0001F308",
-    "\idea": "\U0001F4a1",
-    "\pin": "\U0001F4CC",
-    "\construction": "\U0001F6A7",
-    "\rightarrow": "\U000027a1",
-    "\erocket": "\U0001F680",
-    "\hourglass": "\U000023f3",
-    "\prohibited": "\U0001F6ab",
-    "\checked": "\U00002705",
-    "\smile": "\U0001F642",
-    "\sad": "\U0001F612",
-    "\star": "\U00002B50",
-    "\zzz": "\U0001F4a4",
-    "\mu": "\U000003BC",
-    "\pi": "\U000003C0",
-    "\sigma": "\U000003C3",
+    r"\bomb": "\U0001F4A5",
+    r"\sparks": "\U00002728",
+    r"\ethumbup": "\U0001F44d",
+    r"\etarget": "\U0001F3af",
+    r"\save": "\U0001F4be",
+    r"\noentry": "\U000026d4",
+    r"\video": "\U0001F4fd ",
+    r"\lightning": "\U000026a1",
+    r"\camera": "\U0001F4f8",
+    r"\times": "\U0000274c",
+    r"\world": "\U0001F30d",
+    r"\erainbow": "\U0001F308",
+    r"\idea": "\U0001F4a1",
+    r"\pin": "\U0001F4CC",
+    r"\construction": "\U0001F6A7",
+    r"\rightarrow": "\U000027a1",
+    r"\erocket": "\U0001F680",
+    r"\hourglass": "\U000023f3",
+    r"\prohibited": "\U0001F6ab",
+    r"\checked": "\U00002705",
+    r"\smile": "\U0001F642",
+    r"\sad": "\U0001F612",
+    r"\star": "\U00002B50",
+    r"\zzz": "\U0001F4a4",
+    r"\mu": "\U000003BC",
+    r"\pi": "\U000003C0",
+    r"\sigma": "\U000003C3",
 }
 
 # terminal color print
@@ -562,13 +573,11 @@ def _has_colors(stream):
         return curses.tigetnum("colors") > 2
     except:
         return False
-
-
 #
 _terminal_has_colors = _has_colors(sys.stdout)
 
 
-def _isSequence(arg):
+def _is_sequence(arg):
     # Check if input is iterable.
     if hasattr(arg, "strip"):
         return False
@@ -580,6 +589,11 @@ def _isSequence(arg):
 
 
 def getColor(rgb=None, hsv=None):
+    """Deprecated. Use get_color()"""
+    #print("Deprecated call to getColor(). Use get_color() instead.")
+    return get_color(rgb, hsv)
+
+def get_color(rgb=None, hsv=None):
     """
     Convert a color or list of colors to (r,g,b) format from many different input formats.
 
@@ -599,18 +613,18 @@ def getColor(rgb=None, hsv=None):
     .. hint:: examples/basic/colorcubes.py
     """
     # recursion, return a list if input is list of colors:
-    if _isSequence(rgb) and (len(rgb) > 3 or _isSequence(rgb[0])):
+    if _is_sequence(rgb) and (len(rgb) > 3 or _is_sequence(rgb[0])):
         seqcol = []
         for sc in rgb:
-            seqcol.append(getColor(sc))
+            seqcol.append(get_color(sc))
         return seqcol
 
     # because they are most common:
     if rgb == "r":
         return (0.9960784313725, 0.11764705882352, 0.121568627450980)
-    elif rgb == "g":
+    if rgb == "g":
         return (0.0156862745098, 0.49803921568627, 0.062745098039215)
-    elif rgb == "b":
+    if rgb == "b":
         return (0.0588235294117, 0.0, 0.984313725490196)
 
     if str(rgb).isdigit():
@@ -621,14 +635,12 @@ def getColor(rgb=None, hsv=None):
     else:
         c = rgb
 
-    if _isSequence(c):
+    if _is_sequence(c):
         if c[0] <= 1 and c[1] <= 1 and c[2] <= 1:
             return c  # already rgb
-        else:
-            if len(c) == 3:
-                return list(np.array(c) / 255.0)  # RGB
-            else:
-                return (c[0] / 255.0, c[1] / 255.0, c[2] / 255.0, c[3])  # RGBA
+        if len(c) == 3:
+            return list(np.array(c) / 255.0)  # RGB
+        return (c[0] / 255.0, c[1] / 255.0, c[2] / 255.0, c[3])  # RGBA
 
     elif isinstance(c, str):  # is string
         c = c.replace("grey", "gray").replace(" ", "")
@@ -650,7 +662,7 @@ def getColor(rgb=None, hsv=None):
             rgb255 = list(int(h[i : i + 2], 16) for i in (0, 2, 4))
             rgbh = np.array(rgb255) / 255.0
             if np.sum(rgbh) > 3:
-                vedo.logger.error(f"in getColor(): Wrong hex color {c}")
+                vedo.logger.error(f"in get_color(): Wrong hex color {c}")
                 return (0.5, 0.5, 0.5)
             return tuple(rgbh)
 
@@ -663,24 +675,22 @@ def getColor(rgb=None, hsv=None):
     elif isinstance(c, (int, float)):  # color number
         return palettes[vedo.settings.palette % len(palettes)][abs(int(c)) % 10]
 
-    # print("Unknown color:", c)
     return (0.5, 0.5, 0.5)
 
 
-def getColorName(c):
-    """Find the name of a color."""
-    c = np.array(getColor(c))  # reformat to rgb
+def get_color_name(c):
+    """Find the name of the closest color."""
+    c = np.array(get_color(c))  # reformat to rgb
     mdist = 99.0
     kclosest = ""
     for key in colors:
-        ci = np.array(getColor(key))
+        ci = np.array(get_color(key))
         d = np.linalg.norm(c - ci)
         if d < mdist:
             mdist = d
             kclosest = str(key)
     return kclosest
 
-
 def hsv2rgb(hsv):
     """Convert HSV to RGB color."""
     ma = vtk.vtkMath()
@@ -693,7 +703,7 @@ def rgb2hsv(rgb):
     """Convert RGB to HSV color."""
     ma = vtk.vtkMath()
     hsv = [0, 0, 0]
-    ma.RGBToHSV(getColor(rgb), hsv)
+    ma.RGBToHSV(get_color(rgb), hsv)
     return hsv
 
 
@@ -711,6 +721,11 @@ def hex2rgb(hx):
 
 
 def colorMap(value, name="jet", vmin=None, vmax=None):
+    """Deprecated, use color_map()"""
+    print("Deprecated call to colorMap(), use color_map() instead")
+    return color_map(value, name, vmin, vmax)
+
+def color_map(value, name="jet", vmin=None, vmax=None):
     """
     Map a real value in range [vmin, vmax] to a (r,g,b) color scale.
 
@@ -737,16 +752,16 @@ def colorMap(value, name="jet", vmin=None, vmax=None):
     Example:
         .. code-block:: python
 
-            from vedo import colorMap
+            from vedo import color_map
             import matplotlib.cm as cm
-            print( colorMap(0.2, cm.flag, 0, 1) )
+            print( color_map(0.2, cm.flag, 0, 1) )
 
             # (1.0, 0.809016994374948, 0.6173258487801733)
 
     .. hint:: examples/pyplot/plot_bars.py
         .. image:: https://vedo.embl.es/images/pyplot/plot_bars.png
     """
-    cut = _isSequence(value)  # to speed up later
+    cut = _is_sequence(value)  # to speed up later
 
     if cut:
         values = np.asarray(value)
@@ -756,10 +771,10 @@ def colorMap(value, name="jet", vmin=None, vmax=None):
         values = (values - vmin) / (vmax - vmin)
     else:
         if vmin is None:
-            vedo.logger.warning("in colorMap() you must specify vmin! Assume 0.")
+            vedo.logger.warning("in color_map() you must specify vmin! Assume 0.")
             vmin = 0
         if vmax is None:
-            vedo.logger.warning("in colorMap() you must specify vmax! Assume 1.")
+            vedo.logger.warning("in color_map() you must specify vmax! Assume 1.")
             vmax = 1
         values = [(value - vmin) / (vmax - vmin)]
 
@@ -780,7 +795,7 @@ def colorMap(value, name="jet", vmin=None, vmax=None):
         try:
             cmap = cmaps[name]
         except KeyError:
-            vedo.logger.error(f"in colorMap(), no color map with name {name} or {name}_r")
+            vedo.logger.error(f"in color_map(), no color map with name {name} or {name}_r")
             vedo.logger.error(f"Available color maps are:\n{cmaps.keys()}")
             return np.array([0.5, 0.5, 0.5])
 
@@ -796,11 +811,10 @@ def colorMap(value, name="jet", vmin=None, vmax=None):
 
     if cut:
         return result
-    else:
-        return result[0]
+    return result[0]
 
 
-def buildPalette(color1, color2, N, hsv=True):
+def build_palette(color1, color2, n, hsv=True):
     """
     Generate N colors starting from `color1` to `color2`
     by linear interpolation in HSV or RGB spaces.
@@ -825,17 +839,16 @@ def buildPalette(color1, color2, N, hsv=True):
     if hsv:
         color1 = rgb2hsv(color1)
         color2 = rgb2hsv(color2)
-    c1 = np.array(getColor(color1))
-    c2 = np.array(getColor(color2))
+    c1 = np.array(get_color(color1))
+    c2 = np.array(get_color(color2))
     cols = []
-    for f in np.linspace(0, 1, N - 1, endpoint=True):
+    for f in np.linspace(0, 1, n, endpoint=True):
         c = c1 * (1 - f) + c2 * f
         if hsv:
             c = np.array(hsv2rgb(c))
         cols.append(c)
     return np.array(cols)
 
-
 def buildLUT(
     colorlist,
     vmin=None,
@@ -847,6 +860,33 @@ def buildLUT(
     aboveAlpha=1,
     nanAlpha=1,
     interpolate=False,
+):
+    """Deprecated call to buildLUT(). Please use build_lut()"""
+    print("Warning! Deprecated call to buildLUT(). Please use build_lut() instead")
+    return build_lut(
+        colorlist,
+        vmin,
+        vmax,
+        belowColor,
+        aboveColor,
+        nanColor,
+        belowAlpha,
+        aboveAlpha,
+        nanAlpha,
+        interpolate,
+    )
+
+def build_lut(
+    colorlist,
+    vmin=None,
+    vmax=None,
+    below_color=None,
+    above_color=None,
+    nan_color=None,
+    below_alpha=1,
+    above_alpha=1,
+    nan_alpha=1,
+    interpolate=False,
 ):
     """
     Generate colors in a lookup table (LUT).
@@ -864,22 +904,22 @@ def buildLUT(
     vmax : float
         specify maximum value of scalar range
 
-    belowColor : color
+    below_color : color
         color for scalars below the minimum in range
 
-    belowAlpha : float
+    below_alpha : float
         opacity for scalars below the minimum in range
 
-    aboveColor : color
+    above_color : color
         color for scalars above the maximum in range
 
-    aboveAlpha : float
+    above_alpha : float
         alpha for scalars above the maximum in range
 
-    nanColor : color
+    nan_color : color
         color for invalid (nan) scalars
 
-    nanAlpha : float
+    nan_alpha : float
         alpha for invalid (nan) scalars
 
     interpolate : bool
@@ -898,7 +938,7 @@ def buildLUT(
         else:
             alf = 1
             scalar, col = sc
-        r, g, b = getColor(col)
+        r, g, b = get_color(col)
         ctf.AddRGBPoint(scalar, r, g, b)
         alpha_x.append(scalar)
         alpha_vals.append(alf)
@@ -914,14 +954,14 @@ def buildLUT(
     ctf.SetRange(x0, x1)
     lut.SetRange(x0, x1)
 
-    if belowColor is not None:
-        lut.SetBelowRangeColor(list(getColor(belowColor)) + [belowAlpha])
+    if below_color is not None:
+        lut.SetBelowRangeColor(list(get_color(below_color)) + [below_alpha])
         lut.SetUseBelowRangeColor(True)
-    if aboveColor is not None:
-        lut.SetAboveRangeColor(list(getColor(aboveColor)) + [aboveAlpha])
+    if above_color is not None:
+        lut.SetAboveRangeColor(list(get_color(above_color)) + [above_alpha])
         lut.SetUseAboveRangeColor(True)
-    if nanColor is not None:
-        lut.SetNanColor(list(getColor(nanColor)) + [nanAlpha])
+    if nan_color is not None:
+        lut.SetNanColor(list(get_color(nan_color)) + [nan_alpha])
 
     rgba = (1, 1, 1, 1)
     for i in range(256):
@@ -937,7 +977,7 @@ def buildLUT(
                         alf = c[2]
                     else:
                         alf = 1
-                    rgba = list(getColor(c[1])) + [alf]
+                    rgba = list(get_color(c[1])) + [alf]
                     break
         lut.SetTableValue(i, rgba)
 
@@ -993,7 +1033,7 @@ def printc(
     invert : bool
         invert background and forward colors [False]
 
-    :param box : bool
+    box : bool
         print a box with specified text character ['']
 
     flush : bool
@@ -1013,11 +1053,11 @@ def printc(
     .. hint:: examples/other/printc.py
         .. image:: https://user-images.githubusercontent.com/32848391/50739010-2bfc2b80-11da-11e9-94de-011e50a86e61.jpg
     """
-    if not vedo.settings.enablePrintColor:
+    if not vedo.settings.enable_print_color:
         print(*strings, end=end, flush=flush)
         return
 
-    if not vedo.notebookBackend:
+    if not vedo.notebook_backend:
         if not _terminal_has_colors:
             print(*strings, end=end, flush=flush)
             return
@@ -1045,14 +1085,14 @@ def printc(
 
         special, cseq = "", ""
         oneletter_colors = {
-            "k": "\u001b[30;1m",  # because these are supported by most terminals
-            "r": "\u001b[31;1m",
-            "g": "\u001b[32;1m",
-            "y": "\u001b[33;1m",
-            "b": "\u001b[34;1m",
-            "m": "\u001b[35;1m",
-            "c": "\u001b[36;1m",
-            "w": "\u001b[37;1m",
+            "k": "\u001b[30m",  # because these are supported by most terminals
+            "r": "\u001b[31m",
+            "g": "\u001b[32m",
+            "y": "\u001b[33m",
+            "b": "\u001b[34m",
+            "m": "\u001b[35m",
+            "c": "\u001b[36m",
+            "w": "\u001b[37m",
         }
 
         if c is not None:
@@ -1064,14 +1104,14 @@ def printc(
             if isinstance(c, str) and c in oneletter_colors:
                 cseq += oneletter_colors[c]
             else:
-                r, g, b = getColor(c)  # not all terms support this syntax
+                r, g, b = get_color(c)  # not all terms support this syntax
                 cseq += f"\x1b[38;2;{int(r*255)};{int(g*255)};{int(b*255)}m"
 
         if bc:
-            if bc in oneletter_colors.keys():
+            if bc in oneletter_colors:
                 cseq += oneletter_colors[bc]
             else:
-                r, g, b = getColor(bc)
+                r, g, b = get_color(bc)
                 cseq += f"\x1b[48;2;{int(r*255)};{int(g*255)};{int(b*255)}m"
 
         if box is True:
@@ -1118,7 +1158,11 @@ def printc(
             sys.stdout.write(out + end)
 
     except:  # ------------------------------------------------------------- fallback
-        print(*strings, end=end)
+        try:
+            print(*strings, end=end)
+        except UnicodeEncodeError as e:
+            print(e, end=end)
+            pass
 
     if flush:
         sys.stdout.flush()
@@ -1126,7 +1170,7 @@ def printc(
 
 def printd(*strings, q=False):
     """
-    Print debug information about the evironment where the printd() is called.
+    Print debug information about the environment where the printd() is called.
     Local variables are printed out with their current values.
 
     Use ``q`` to quit (exit) python session after the printd call.
@@ -1159,7 +1203,7 @@ def printd(*strings, q=False):
 
         var = var.replace("vtkmodules.", "")
         print("      \x1b[37m", loc, "\t\t=", var[:60].replace("\n", ""), reset)
-        if vedo.utils.isSequence(obj) and len(obj) > 4:
+        if vedo.utils.is_sequence(obj) and len(obj) > 4:
             print('           \x1b[37m\x1b[2m\x1b[3m len:', len(obj),
                   ' min:', vedo.utils.precision(min(obj), 4),
                   ' max:', vedo.utils.precision(max(obj), 4),
