@@ -1,5 +1,12 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 import numpy as np
-import vtk
+
+try:
+    import vedo.vtkclasses as vtk
+except ImportError:
+    import vtkmodules.all as vtk
+
 import vedo
 from vedo import colors
 from vedo import utils
@@ -44,6 +51,7 @@ def _get_img(obj, flip=False):
         varb = utils.numpy2vtk(arr, dtype=np.uint8, name="RGBA")
         img = vtk.vtkImageData()
         img.SetDimensions(obj.shape[1], obj.shape[0], 1)
+
         img.GetPointData().AddArray(varb)
         img.GetPointData().SetActiveScalars("RGBA")
 
@@ -87,7 +95,7 @@ class MatplotlibPicture(vtk.vtkActor2D):
         self.data = np.frombuffer(fig.canvas.tostring_rgb(), dtype=np.uint8)
         self.data = self.data.reshape(fig.canvas.get_width_height()[::-1] + (3,))
         self.picture = Picture(self.data)
-        if len(size):
+        if len(size) > 0:
             self.picture.resize(np.array(size)*scale)
         if scale != 1:
             self.picture.scale(scale)
@@ -116,10 +124,13 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
     Use `Picture.dimensions()` to access the number of pixels in x and y.
 
-    |rotateImage| |rotateImage.py|_
+    Parameters
+    ----------
+    channels :  int, list
+        only select these specific rgba channels (useful to remove alpha)
 
-    :param int,list channels: only select these specific rgba channels (useful to remove alpha)
-    :param bool flip: flip xy axis convention (when input is a numpy array)
+    flip : bool
+        flip xy axis convention (when input is a numpy array)
     """
 
     def __init__(self, obj=None, channels=3, flip=False):
@@ -127,7 +138,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         vtk.vtkImageActor.__init__(self)
         vedo.base.Base3DProp.__init__(self)
 
-        if utils.isSequence(obj) and len(obj):  # passing array
+        if utils.is_sequence(obj) and len(obj):  # passing array
             img = _get_img(obj, flip)
 
         elif isinstance(obj, vtk.vtkImageData):
@@ -146,7 +157,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
                 picr = vtk.vtkBMPReader()
             elif fname.endswith(".tif") or fname.endswith(".tiff"):
                 picr = vtk.vtkTIFFReader()
-                picr.SetOrientationType(vedo.settings.tiffOrientationType)
+                picr.SetOrientationType(vedo.settings.tiff_orientation_type)
             else:
                 colors.printc("Cannot understand picture format", obj, c="r")
                 return
@@ -222,6 +233,42 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             pic.SetPosition(self.GetPosition())
         return pic
 
+    def cmap(self, name, vmin=None, vmax=None):
+        """Colorize a picture with a colormap representing pixel intensity"""
+        n = self._data.GetPointData().GetNumberOfComponents()
+        if n > 1:
+            ecr = vtk.vtkImageExtractComponents()
+            ecr.SetInputData(self._data)
+            ecr.SetComponents(0, 1, 2)
+            ecr.Update()
+            ilum = vtk.vtkImageMagnitude()
+            ilum.SetInputData(self._data)
+            ilum.Update()
+            img = ilum.GetOutput()
+        else:
+            img = self._data
+
+        lut = vtk.vtkLookupTable()
+        _vmin, _vmax = img.GetScalarRange()
+        if vmin is not None:
+            _vmin = vmin
+        if vmax is not None:
+            _vmax = vmax
+        lut.SetRange(_vmin, _vmax)
+
+        ncols = 256
+        lut.SetNumberOfTableValues(ncols)
+        cols = colors.color_map(range(ncols), name, 0, ncols)
+        for i, c in enumerate(cols):
+            lut.SetTableValue(i, *c)
+        lut.Build()
+
+        imap = vtk.vtkImageMapToColors()
+        imap.SetLookupTable(lut)
+        imap.SetInputData(img)
+        imap.Update()
+        return self._update(imap.GetOutput())
+
     def extent(self, ext=None):
         """
         Get or set the physical extent that the picture spans.
@@ -229,18 +276,17 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         """
         if ext is None:
             return self._data.GetExtent()
-        else:
-            self._data.SetExtent(ext[0], ext[1], ext[2], ext[3], 0, 0)
-            self._mapper.Modified()
-            return self
+
+        self._data.SetExtent(ext[0], ext[1], ext[2], ext[3], 0, 0)
+        self._mapper.Modified()
+        return self
 
     def alpha(self, a=None):
         """Set/get picture's transparency in the rendering scene."""
         if a is not None:
             self.GetProperty().SetOpacity(a)
             return self
-        else:
-            return self.GetProperty().GetOpacity()
+        return self.GetProperty().GetOpacity()
 
     def level(self, value=None):
         """Get/Set the image color level (brightness) in the rendering scene."""
@@ -259,11 +305,22 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
     def crop(self, top=None, bottom=None, right=None, left=None, pixels=False):
         """Crop picture.
 
-        :param float top: fraction to crop from the top margin
-        :param float bottom: fraction to crop from the bottom margin
-        :param float left: fraction to crop from the left margin
-        :param float right: fraction to crop from the right margin
-        :param bool pixels: units are pixels
+        Parameters
+        ----------
+        top : float
+            fraction to crop from the top margin
+
+        bottom : float
+            fraction to crop from the bottom margin
+
+        left : float
+            fraction to crop from the left margin
+
+        right : float
+            fraction to crop from the right margin
+
+        pixels : bool
+            units are pixels
         """
         extractVOI = vtk.vtkExtractVOI()
         extractVOI.SetInputData(self._data)
@@ -298,7 +355,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         pf = vtk.vtkImageConstantPad()
         pf.SetInputData(self._data)
         pf.SetConstant(value)
-        if utils.isSequence(pixels):
+        if utils.is_sequence(pixels):
             pf.SetOutputWholeExtent(
                 x0 - pixels[0], x1 + pixels[1], y0 - pixels[2], y1 + pixels[3], 0, 0
             )
@@ -324,9 +381,9 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             shift in x and y in pixels. The default is 4.
         """
         x0, x1, y0, y1, z0, z1 = self._data.GetExtent()
-        constantPad = vtk.vtkImageMirrorPad()
-        constantPad.SetInputData(self._data)
-        constantPad.SetOutputWholeExtent(
+        constant_pad = vtk.vtkImageMirrorPad()
+        constant_pad.SetInputData(self._data)
+        constant_pad.SetOutputWholeExtent(
             int(x0 + shift[0] + 0.5),
             int(x1 * nx + shift[0] + 0.5),
             int(y0 + shift[1] + 0.5),
@@ -334,8 +391,8 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             z0,
             z1,
         )
-        constantPad.Update()
-        return Picture(constantPad.GetOutput())
+        constant_pad.Update()
+        return Picture(constant_pad.GetOutput())
 
     def append(self, pictures, axis="z", preserveExtents=False):
         """
@@ -346,23 +403,30 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         The origin and spacing of all other inputs are ignored.
         All inputs must have the same scalar type.
 
-        :param int,str axis: axis expanded to hold the multiple images.
-        :param bool preserveExtents: if True, the extent of the inputs is used to place
+        Parameters
+        ----------
+        axis : int, str
+            axis expanded to hold the multiple images
+
+        preserveExtents : bool
+            if True, the extent of the inputs is used to place
             the image in the output. The whole extent of the output is the union of the input
             whole extents. Any portion of the output not covered by the inputs is set to zero.
             The origin and spacing is taken from the first input.
 
+        Example
+        -------
         .. code-block:: python
 
             from vedo import Picture, dataurl
             pic = Picture(dataurl+'dog.jpg').pad()
             pic.append([pic,pic,pic], axis='y')
             pic.append([pic,pic,pic,pic], axis='x')
-            pic.show(axes=1)
+            pic.show(axes=1).close()
         """
         ima = vtk.vtkImageAppend()
         ima.SetInputData(self._data)
-        if not utils.isSequence(pictures):
+        if not utils.is_sequence(pictures):
             pictures = [pictures]
         for p in pictures:
             if isinstance(p, vtk.vtkImageData):
@@ -382,11 +446,11 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         """Resize the image resolution by specifying the number of pixels in width and height.
         If left to zero, it will be automatically calculated to keep the original aspect ratio.
 
-        :param list,float newsize: shape of picture as [npx, npy], or as a fraction.
+        newsize is the shape of picture as [npx, npy], or it can be also expressed as a fraction.
         """
         old_dims = np.array(self._data.GetDimensions())
 
-        if not utils.isSequence(newsize):
+        if not utils.is_sequence(newsize):
             newsize = (old_dims * newsize + 0.5).astype(int)
 
         if not newsize[1]:
@@ -453,7 +517,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
         reslice = vtk.vtkImageReslice()
         reslice.SetMirror(mirroring)
-        c = np.array(colors.getColor(bc)) * 255
+        c = np.array(colors.get_color(bc)) * 255
         reslice.SetBackgroundColor([c[0], c[1], c[2], alpha * 255])
         reslice.SetInputData(self._data)
         reslice.SetResliceTransform(transform)
@@ -505,12 +569,12 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         gsf.SetDimensionality(2)
         gsf.SetInputData(self._data)
         if radius is not None:
-            if utils.isSequence(radius):
+            if utils.is_sequence(radius):
                 gsf.SetRadiusFactors(radius[0], radius[1])
             else:
                 gsf.SetRadiusFactor(radius)
 
-        if utils.isSequence(sigma):
+        if utils.is_sequence(sigma):
             gsf.SetStandardDeviations(sigma[0], sigma[1])
         else:
             gsf.SetStandardDeviation(sigma)
@@ -539,7 +603,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
                 import vedo
                 p = vedo.Picture(vedo.dataurl+'images/dog.jpg').bw()
-                vedo.show(p, p.clone().enhance(), N=2, mode='image')
+                vedo.show(p, p.clone().enhance(), N=2, mode='image', zoom='tight')
         """
         img = self._data
         scalarRange = img.GetPointData().GetScalars().GetRange()
@@ -560,24 +624,29 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         subtr.SetOperationToSubtract()
         subtr.Update()
 
-        colorWindow = scalarRange[1] - scalarRange[0]
-        colorLevel = colorWindow / 2
-        originalColor = vtk.vtkImageMapToWindowLevelColors()
-        originalColor.SetWindow(colorWindow)
-        originalColor.SetLevel(colorLevel)
-        originalColor.SetInputData(subtr.GetOutput())
-        originalColor.Update()
-        return self._update(originalColor.GetOutput())
+        color_window = scalarRange[1] - scalarRange[0]
+        color_level = color_window / 2
+        original_color = vtk.vtkImageMapToWindowLevelColors()
+        original_color.SetWindow(color_window)
+        original_color.SetLevel(color_level)
+        original_color.SetInputData(subtr.GetOutput())
+        original_color.Update()
+        return self._update(original_color.GetOutput())
 
     def fft(self, mode="magnitude", logscale=12, center=True):
-        """Fast Fourier transform of a picture.
+        """
+        Fast Fourier transform of a picture.
 
-        :param float logscale: if non-zero, take the logarithm of the
-            intensity and scale it by this factor.
+        Parameters
+        ----------
+        logscale : float
+            if non-zero, take the logarithm of the intensity and scale it by this factor.
 
-        :param str mode: either [magnitude, real, imaginary, complex], compute the
-            point array data accordingly.
-        :param bool center: shift constant zero-frequency to the center of the image for display.
+        mode : str
+            either [magnitude, real, imaginary, complex], compute the point array data accordingly.
+
+        center : bool
+            shift constant zero-frequency to the center of the image for display.
             (FFT converts spatial images into frequency space, but puts the zero frequency at the origin)
         """
         ffti = vtk.vtkImageFFT()
@@ -590,17 +659,17 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             mag.Update()
             out = mag.GetOutput()
         elif "real" in mode:
-            extractRealFilter = vtk.vtkImageExtractComponents()
-            extractRealFilter.SetInputData(ffti.GetOutput())
-            extractRealFilter.SetComponents(0)
-            extractRealFilter.Update()
-            out = extractRealFilter.GetOutput()
+            erf = vtk.vtkImageExtractComponents()
+            erf.SetInputData(ffti.GetOutput())
+            erf.SetComponents(0)
+            erf.Update()
+            out = erf.GetOutput()
         elif "imaginary" in mode:
-            extractImgFilter = vtk.vtkImageExtractComponents()
-            extractImgFilter.SetInputData(ffti.GetOutput())
-            extractImgFilter.SetComponents(1)
-            extractImgFilter.Update()
-            out = extractImgFilter.GetOutput()
+            eimf = vtk.vtkImageExtractComponents()
+            eimf.SetInputData(ffti.GetOutput())
+            eimf.SetComponents(1)
+            eimf.Update()
+            out = eimf.GetOutput()
         elif "complex" in mode:
             out = ffti.GetOutput()
         else:
@@ -636,17 +705,17 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             mag.Update()
             out = mag.GetOutput()
         elif "real" in mode:
-            extractRealFilter = vtk.vtkImageExtractComponents()
-            extractRealFilter.SetInputData(ffti.GetOutput())
-            extractRealFilter.SetComponents(0)
-            extractRealFilter.Update()
-            out = extractRealFilter.GetOutput()
+            erf = vtk.vtkImageExtractComponents()
+            erf.SetInputData(ffti.GetOutput())
+            erf.SetComponents(0)
+            erf.Update()
+            out = erf.GetOutput()
         elif "imaginary" in mode:
-            extractImgFilter = vtk.vtkImageExtractComponents()
-            extractImgFilter.SetInputData(ffti.GetOutput())
-            extractImgFilter.SetComponents(1)
-            extractImgFilter.Update()
-            out = extractImgFilter.GetOutput()
+            eimf = vtk.vtkImageExtractComponents()
+            eimf.SetInputData(ffti.GetOutput())
+            eimf.SetComponents(1)
+            eimf.Update()
+            out = eimf.GetOutput()
         elif "complex" in mode:
             out = ffti.GetOutput()
         else:
@@ -662,15 +731,20 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         This function applies a high pass Butterworth filter that attenuates the
         frequency domain image with the function
 
-        |G_Of_Omega|
-
         The gradual attenuation of the filter is important.
         A simple high-pass filter would simply mask a set of pixels in the frequency domain,
         but the abrupt transition would cause a ringing effect in the spatial domain.
 
-        :param list lowcutoff:  the cutoff frequencies
-        :param list highcutoff: the cutoff frequencies
-        :param int order: order determines sharpness of the cutoff curve
+        Parameters
+        ----------
+        lowcutoff : list
+            the cutoff frequencies
+
+        highcutoff : list
+            the cutoff frequencies
+
+        order : int
+            order determines sharpness of the cutoff curve
         """
         # https://lorensen.github.io/VTKExamples/site/Cxx/ImageProcessing/IdealHighPass
         fft = vtk.vtkImageFFT()
@@ -679,33 +753,33 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         out = fft.GetOutput()
 
         if highcutoff:
-            butterworthLowPass = vtk.vtkImageButterworthLowPass()
-            butterworthLowPass.SetInputData(out)
-            butterworthLowPass.SetCutOff(highcutoff)
-            butterworthLowPass.SetOrder(order)
-            butterworthLowPass.Update()
-            out = butterworthLowPass.GetOutput()
+            blp = vtk.vtkImageButterworthLowPass()
+            blp.SetInputData(out)
+            blp.SetCutOff(highcutoff)
+            blp.SetOrder(order)
+            blp.Update()
+            out = blp.GetOutput()
 
         if lowcutoff:
-            butterworthHighPass = vtk.vtkImageButterworthHighPass()
-            butterworthHighPass.SetInputData(out)
-            butterworthHighPass.SetCutOff(lowcutoff)
-            butterworthHighPass.SetOrder(order)
-            butterworthHighPass.Update()
-            out = butterworthHighPass.GetOutput()
+            bhp = vtk.vtkImageButterworthHighPass()
+            bhp.SetInputData(out)
+            bhp.SetCutOff(lowcutoff)
+            bhp.SetOrder(order)
+            bhp.Update()
+            out = bhp.GetOutput()
 
-        butterworthRfft = vtk.vtkImageRFFT()
-        butterworthRfft.SetInputData(out)
-        butterworthRfft.Update()
+        rfft = vtk.vtkImageRFFT()
+        rfft.SetInputData(out)
+        rfft.Update()
 
-        butterworthReal = vtk.vtkImageExtractComponents()
-        butterworthReal.SetInputData(butterworthRfft.GetOutput())
-        butterworthReal.SetComponents(0)
-        butterworthReal.Update()
+        ecomp = vtk.vtkImageExtractComponents()
+        ecomp.SetInputData(rfft.GetOutput())
+        ecomp.SetComponents(0)
+        ecomp.Update()
 
         caster = vtk.vtkImageCast()
         caster.SetOutputScalarTypeToUnsignedChar()
-        caster.SetInputData(butterworthReal.GetOutput())
+        caster.SetInputData(ecomp.GetOutput())
         caster.Update()
         return self._update(caster.GetOutput())
 
@@ -715,7 +789,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         """
         blf = vtk.vtkImageBlend()
         blf.AddInputData(self._data)
-        blf.AddInputData(pic._data)
+        blf.AddInputData(pic.inputdata())
         blf.SetOpacity(0, alpha1)
         blf.SetOpacity(1, alpha2)
         blf.SetBlendModeToNormal()
@@ -792,7 +866,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         reslice.SetResliceTransform(transform)
         reslice.SetInterpolationModeToCubic()
         reslice.SetMirror(mirroring)
-        c = np.array(colors.getColor(bc)) * 255
+        c = np.array(colors.get_color(bc)) * 255
         reslice.SetBackgroundColor([c[0], c[1], c[2], alpha * 255])
         reslice.Update()
         self.transform = transform
@@ -823,7 +897,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             pic1 = Picture("https://aws.glamour.es/prod/designs/v1/assets/620x459/547577.jpg")
             pic2 = pic1.clone().invert()
             pic3 = pic1.clone().binarize()
-            show(pic1, pic2, pic3, N=3, bg="blue9")
+            show(pic1, pic2, pic3, N=3, bg="blue9").close()
         """
         rgb = self.tonumpy()
         if rgb.ndim == 3:
@@ -898,10 +972,10 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         self._data.GetPointData().GetScalars().SetName("RGBA")
         gr.inputdata().GetPointData().AddArray(self._data.GetPointData().GetScalars())
         gr.inputdata().GetPointData().SetActiveScalars("RGBA")
-        gr._mapper.SetArrayName("RGBA")
-        gr._mapper.SetScalarModeToUsePointData()
-        # gr._mapper.SetColorModeToDirectScalars()
-        gr._mapper.ScalarVisibilityOn()
+        gr.mapper().SetArrayName("RGBA")
+        gr.mapper().SetScalarModeToUsePointData()
+        # gr.mapper().SetColorModeToDirectScalars()
+        gr.mapper().ScalarVisibilityOn()
         gr.name = self.name
         gr.filename = self.filename
         return gr
@@ -930,7 +1004,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         .. code-block:: python
 
                 import vedo
-                pic = vedo.Picture("dog.jpg")
+                pic = vedo.Picture(vedo.dataurl+"images/dog.jpg")
                 pic.rectangle([100,300], [100,200], c='green4', alpha=0.7)
                 pic.line([100,100],[400,500], lw=2, alpha=1)
                 pic.triangle([250,300], [100,300], [200,400])
@@ -939,12 +1013,11 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         x1, x2 = xspan
         y1, y2 = yspan
 
-        r, g, b = vedo.colors.getColor(c)
+        r, g, b = vedo.colors.get_color(c)
         c = np.array([r, g, b]) * 255
         c = c.astype(np.uint8)
 
-        if alpha > 1:
-            alpha = 1
+        alpha = min(alpha, 1)
         if alpha <= 0:
             return self
         alpha2 = alpha
@@ -977,11 +1050,11 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         x1, x2 = p1
         y1, y2 = p2
 
-        r, g, b = vedo.colors.getColor(c)
+        r, g, b = vedo.colors.get_color(c)
         c = np.array([r, g, b]) * 255
         c = c.astype(np.uint8)
-        if alpha > 1:
-            alpha = 1
+
+        alpha = min(alpha, 1)
         if alpha <= 0:
             return self
         alpha2 = alpha
@@ -1015,12 +1088,11 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         x2, y2 = p2
         x3, y3 = p3
 
-        r, g, b = vedo.colors.getColor(c)
+        r, g, b = vedo.colors.get_color(c)
         c = np.array([r, g, b]) * 255
         c = c.astype(np.uint8)
 
-        if alpha > 1:
-            alpha = 1
+        alpha = min(alpha, 1)
         if alpha <= 0:
             return self
         alpha2 = alpha
@@ -1057,7 +1129,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 #        """Draw a box."""
 #        x1, y1 = center
 #
-#        r,g,b = vedo.colors.getColor(c)
+#        r,g,b = vedo.colors.get_color(c)
 #        c = np.array([r,g,b]) * 255
 #        c = c.astype(np.uint8)
 #
@@ -1114,7 +1186,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
         tp = vtk.vtkTextProperty()
         tp.BoldOff()
-        tp.SetColor(colors.getColor(c))
+        tp.SetColor(colors.get_color(c))
         tp.SetJustificationToLeft()
         if "top" in justify:
             tp.SetVerticalJustificationToTop()
@@ -1133,10 +1205,10 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         elif font.lower() == "arial": tp.SetFontFamilyToArial()
         else:
             tp.SetFontFamily(vtk.VTK_FONT_FILE)
-            tp.SetFontFile(utils.getFontPath(font))
+            tp.SetFontFile(utils.get_font_path(font))
 
         if bg:
-            bgcol = colors.getColor(bg)
+            bgcol = colors.get_color(bg)
             tp.SetBackgroundColor(bgcol)
             tp.SetBackgroundOpacity(alpha * 0.5)
             tp.SetFrameColor(bgcol)
