@@ -3,10 +3,13 @@ import os
 from deprecated import deprecated
 
 import numpy as np
-import vtk
+
+try:
+    import vedo.vtkclasses as vtk
+except ImportError:
+    import vtkmodules.all as vtk
 
 import vedo
-from vedo import colors
 from vedo import utils
 from vedo.base import Base3DProp
 from vedo.base import BaseGrid
@@ -21,26 +24,9 @@ __all__ = [
     "BaseVolume",  # included to generate documentation in pydoc
     "Volume",
     "VolumeSlice",
-    "volumeFromMesh",  # deprecated
-    "interpolateToVolume",  # deprecated
 ]
 
 
-##########################################################################
-@deprecated(reason=colors.red + "Please use mesh.signedVolume()" + colors.reset)
-def volumeFromMesh(mesh, **kwargs):
-    """Deprecated. Please use ``mesh.signedVolume()``"""
-    return mesh.signedVolume(
-        bounds=kwargs["bounds"], dims=kwargs["dims"], invert=kwargs["negate"]
-    )
-
-
-@deprecated(reason=colors.red + "Please use Points.tovolume()" + colors.reset)
-def interpolateToVolume(mesh, **kwargs):
-    """Deprecated. Please use ``Points.tovolume()``"""
-    return mesh.tovolume(**kwargs)
-
-
 ##########################################################################
 class BaseVolume:
     """Base class. Do not instantiate."""
@@ -48,6 +34,7 @@ class BaseVolume:
     def __init__(self):
         self._data = None
         self._mapper = None
+        self.transform = None
 
     def _update(self, img):
         self._data = img
@@ -76,11 +63,6 @@ class BaseVolume:
         """Return the underlying `vtkImagaData` object."""
         return self._data
 
-    @deprecated(reason=colors.red + "Please use tonumpy()" + colors.reset)
-    def getDataArray(self):
-        """Deprecated. Please use tonumpy()"""
-        return self.tonumpy()
-
     def tonumpy(self):
         """
         Get read-write access to voxels of a Volume object as a numpy array.
@@ -116,7 +98,12 @@ class BaseVolume:
         """Return the nr. of voxels in the 3 dimensions."""
         return np.array(self._data.GetDimensions())
 
+    @deprecated(reason=vedo.colors.red + "Please use scalar_range()" + vedo.colors.reset)
     def scalarRange(self):
+        "Deprecated. Please use scalar_range()"
+        return self.scalar_range()
+
+    def scalar_range(self):
         """Return the range of the scalar values."""
         return np.array(self._data.GetScalarRange())
 
@@ -125,8 +112,7 @@ class BaseVolume:
         if s is not None:
             self._data.SetSpacing(s)
             return self
-        else:
-            return np.array(self._data.GetSpacing())
+        return np.array(self._data.GetSpacing())
 
     def origin(self, s=None):
         """Set/get the origin of the volumetric dataset."""
@@ -135,8 +121,7 @@ class BaseVolume:
         if s is not None:
             self._data.SetOrigin(s)
             return self
-        else:
-            return np.array(self._data.GetOrigin())
+        return np.array(self._data.GetOrigin())
 
     def center(self, center=None):
         """Set/get the volume coordinates of its center.
@@ -147,10 +132,9 @@ class BaseVolume:
             self._update(self._data)
             self.pos(0, 0, 0)
             return self
-        else:
-            return np.array(self._data.GetCenter())
+        return np.array(self._data.GetCenter())
 
-    def permuteAxes(self, x, y, z):
+    def permute_axes(self, x, y, z):
         """Reorder the axes of the Volume by specifying
         the input axes which are supposed to become the new X, Y, and Z."""
         imp = vtk.vtkImagePermute()
@@ -159,7 +143,7 @@ class BaseVolume:
         imp.Update()
         return self._update(imp.GetOutput())
 
-    def resample(self, newSpacing, interpolation=1):
+    def resample(self, new_spacing, interpolation=1):
         """
         Resamples a ``Volume`` to be larger or smaller.
 
@@ -168,7 +152,7 @@ class BaseVolume:
 
         Parameters
         ----------
-        newSpacing : list
+        new_spacing : list
             a list of 3 new spacings for the 3 axes
 
         interpolation : int
@@ -177,8 +161,8 @@ class BaseVolume:
         rsp = vtk.vtkImageResample()
         oldsp = self.spacing()
         for i in range(3):
-            if oldsp[i] != newSpacing[i]:
-                rsp.SetAxisOutputSpacing(i, newSpacing[i])
+            if oldsp[i] != new_spacing[i]:
+                rsp.SetAxisOutputSpacing(i, new_spacing[i])
         rsp.InterpolateOn()
         rsp.SetInterpolationMode(interpolation)
         rsp.OptimizationOn()
@@ -194,7 +178,7 @@ class BaseVolume:
         self.property.SetInterpolationType(itype)
         return self
 
-    def threshold(self, above=None, below=None, replace=None, replaceOut=None):
+    def threshold(self, above=None, below=None, replace=None, replace_value=None):
         """
         Binary or continuous volume thresholding.
         Find the voxels that contain a value above/below the input values
@@ -228,9 +212,9 @@ class BaseVolume:
         else:
             th.SetReplaceIn(False)
 
-        if replaceOut is not None:
+        if replace_value is not None:
             th.SetReplaceOut(True)
-            th.SetOutValue(replaceOut)
+            th.SetOutValue(replace_value)
         else:
             th.SetReplaceOut(False)
 
@@ -292,7 +276,7 @@ class BaseVolume:
         extractVOI.Update()
         return self._update(extractVOI.GetOutput())
 
-    def append(self, volumes, axis="z", preserveExtents=False):
+    def append(self, volumes, axis="z", preserve_extents=False):
         """
         Take the components from multiple inputs and merges them into one output.
         Except for the append axis, all inputs must have the same extent.
@@ -306,7 +290,7 @@ class BaseVolume:
         axis : int, str
             axis expanded to hold the multiple images
 
-        preserveExtents : bool
+        preserve_extents : bool
             if True, the extent of the inputs is used to place
             the image in the output. The whole extent of the output is the union of the input
             whole extents. Any portion of the output not covered by the inputs is set to zero.
@@ -321,14 +305,14 @@ class BaseVolume:
         """
         ima = vtk.vtkImageAppend()
         ima.SetInputData(self.imagedata())
-        if not utils.isSequence(volumes):
+        if not utils.is_sequence(volumes):
             volumes = [volumes]
         for volume in volumes:
             if isinstance(volume, vtk.vtkImageData):
                 ima.AddInputData(volume)
             else:
                 ima.AddInputData(volume.imagedata())
-        ima.SetPreserveExtents(preserveExtents)
+        ima.SetPreserveExtents(preserve_extents)
         if axis == "x":
             axis = 0
         elif axis == "y":
@@ -360,14 +344,6 @@ class BaseVolume:
         norm.Update()
         return self._update(norm.GetOutput())
 
-    def scaleVoxels(self, scale=1):
-        """Scale the voxel content by factor `scale`."""
-        rsl = vtk.vtkImageReslice()
-        rsl.SetInputData(self.imagedata())
-        rsl.SetScalarScale(scale)
-        rsl.Update()
-        return self._update(rsl.GetOutput())
-
     def mirror(self, axis="x"):
         """
         Mirror flip along one of the cartesian axes.
@@ -408,29 +384,29 @@ class BaseVolume:
             mf.SetInputData(image1)
             mf.Update()
             return Volume(mf.GetOutput())
-        elif op in ["mag"]:
+        if op in ["mag"]:
             mf = vtk.vtkImageMagnitude()
             mf.SetInputData(image1)
             mf.Update()
             return Volume(mf.GetOutput())
-        elif op in ["dot", "dotproduct"]:
+        if op in ["dot", "dotproduct"]:
             mf = vtk.vtkImageDotProduct()
             mf.SetInput1Data(image1)
             mf.SetInput2Data(volume2.imagedata())
             mf.Update()
             return Volume(mf.GetOutput())
-        elif op in ["grad", "gradient"]:
+        if op in ["grad", "gradient"]:
             mf = vtk.vtkImageGradient()
             mf.SetDimensionality(3)
             mf.SetInputData(image1)
             mf.Update()
             return Volume(mf.GetOutput())
-        elif op in ["div", "divergence"]:
+        if op in ["div", "divergence"]:
             mf = vtk.vtkImageDivergence()
             mf.SetInputData(image1)
             mf.Update()
             return Volume(mf.GetOutput())
-        elif op in ["laplacian"]:
+        if op in ["laplacian"]:
             mf = vtk.vtkImageLaplacian()
             mf.SetDimensionality(3)
             mf.SetInputData(image1)
@@ -442,13 +418,15 @@ class BaseVolume:
 
         K = None
 
-        if isinstance(volume2, (int, float)):
+        if utils.is_number(volume2):
             K = volume2
             mat.SetConstantK(K)
             mat.SetConstantC(K)
+
         elif volume2 is not None:  # assume image2 is a constant value
             mat.SetInput2Data(volume2.imagedata())
 
+        # ###########################
         if op in ["+", "add", "plus"]:
             if K:
                 mat.SetOperationToAddConstant()
@@ -457,7 +435,7 @@ class BaseVolume:
 
         elif op in ["-", "subtract", "minus"]:
             if K:
-                mat.SetConstantC(-K)
+                mat.SetConstantC(-float(K))
                 mat.SetOperationToAddConstant()
             else:
                 mat.SetOperationToSubtract()
@@ -505,7 +483,7 @@ class BaseVolume:
         mat.Update()
         return self._update(mat.GetOutput())
 
-    def frequencyPassFilter(self, lowcutoff=None, highcutoff=None, order=1):
+    def frequency_pass_filter(self, low_cutoff=None, high_cutoff=None, order=1):
         """
         Low-pass and high-pass filtering become trivial in the frequency domain.
         A portion of the pixels/voxels are simply masked or attenuated.
@@ -518,10 +496,10 @@ class BaseVolume:
 
         Parameters
         ----------
-        lowcutoff : list
+        low_cutoff : list
             the cutoff frequencies for x, y and z
 
-        highcutoff : list
+        high_cutoff : list
             the cutoff frequencies for x, y and z
 
         order : int
@@ -533,33 +511,33 @@ class BaseVolume:
         fft.Update()
         out = fft.GetOutput()
 
-        if highcutoff:
-            butterworthLowPass = vtk.vtkImageButterworthLowPass()
-            butterworthLowPass.SetInputData(out)
-            butterworthLowPass.SetCutOff(highcutoff)
-            butterworthLowPass.SetOrder(order)
-            butterworthLowPass.Update()
-            out = butterworthLowPass.GetOutput()
+        if high_cutoff:
+            blp = vtk.vtkImageButterworthLowPass()
+            blp.SetInputData(out)
+            blp.SetCutOff(high_cutoff)
+            blp.SetOrder(order)
+            blp.Update()
+            out = blp.GetOutput()
 
-        if lowcutoff:
-            butterworthHighPass = vtk.vtkImageButterworthHighPass()
-            butterworthHighPass.SetInputData(out)
-            butterworthHighPass.SetCutOff(lowcutoff)
-            butterworthHighPass.SetOrder(order)
-            butterworthHighPass.Update()
-            out = butterworthHighPass.GetOutput()
+        if low_cutoff:
+            bhp = vtk.vtkImageButterworthHighPass()
+            bhp.SetInputData(out)
+            bhp.SetCutOff(low_cutoff)
+            bhp.SetOrder(order)
+            bhp.Update()
+            out = bhp.GetOutput()
 
-        butterworthRfft = vtk.vtkImageRFFT()
-        butterworthRfft.SetInputData(out)
-        butterworthRfft.Update()
+        rfft = vtk.vtkImageRFFT()
+        rfft.SetInputData(out)
+        rfft.Update()
 
-        butterworthReal = vtk.vtkImageExtractComponents()
-        butterworthReal.SetInputData(butterworthRfft.GetOutput())
-        butterworthReal.SetComponents(0)
-        butterworthReal.Update()
-        return self._update(butterworthReal.GetOutput())
+        ecomp = vtk.vtkImageExtractComponents()
+        ecomp.SetInputData(rfft.GetOutput())
+        ecomp.SetComponents(0)
+        ecomp.Update()
+        return self._update(ecomp.GetOutput())
 
-    def gaussianSmooth(self, sigma=(2, 2, 2), radius=None):
+    def smooth_gaussian(self, sigma=(2, 2, 2), radius=None):
         """
         Performs a convolution of the input Volume with a gaussian.
 
@@ -576,26 +554,26 @@ class BaseVolume:
         gsf = vtk.vtkImageGaussianSmooth()
         gsf.SetDimensionality(3)
         gsf.SetInputData(self.imagedata())
-        if utils.isSequence(sigma):
+        if utils.is_sequence(sigma):
             gsf.SetStandardDeviations(sigma)
         else:
             gsf.SetStandardDeviation(sigma)
         if radius is not None:
-            if utils.isSequence(radius):
+            if utils.is_sequence(radius):
                 gsf.SetRadiusFactors(radius)
             else:
                 gsf.SetRadiusFactor(radius)
         gsf.Update()
         return self._update(gsf.GetOutput())
 
-    def medianSmooth(self, neighbours=(2, 2, 2)):
+    def smooth_median(self, neighbours=(2, 2, 2)):
         """
         Median filter that replaces each pixel with the median value
         from a rectangular neighborhood around that pixel.
         """
         imgm = vtk.vtkImageMedian3D()
         imgm.SetInputData(self.imagedata())
-        if utils.isSequence(neighbours):
+        if utils.is_sequence(neighbours):
             imgm.SetKernelSize(neighbours[0], neighbours[1], neighbours[2])
         else:
             imgm.SetKernelSize(neighbours, neighbours, neighbours)
@@ -649,7 +627,7 @@ class BaseVolume:
         mpts = vedo.Points(v2p.GetOutput())
         return mpts
 
-    def euclideanDistance(self, anisotropy=False, maxDistance=None):
+    def euclidean_distance(self, anisotropy=False, max_distance=None):
         """
         Implementation of the Euclidean DT (Distance Transform) using Saito's algorithm.
         The distance map produced contains the square of the Euclidean distance values.
@@ -662,8 +640,8 @@ class BaseVolume:
         anisotropy : bool
             used to define whether Spacing should be used in the computation of the distances.
 
-        maxDistance : bool
-            any distance bigger than maxDistance will not be
+        max_distance : bool
+            any distance bigger than max_distance will not be
             computed but set to this specified value instead.
 
         .. hint:: examples/volumetric/euclDist.py
@@ -671,14 +649,14 @@ class BaseVolume:
         euv = vtk.vtkImageEuclideanDistance()
         euv.SetInputData(self._data)
         euv.SetConsiderAnisotropy(anisotropy)
-        if maxDistance is not None:
+        if max_distance is not None:
             euv.InitializeOn()
-            euv.SetMaximumDistance(maxDistance)
+            euv.SetMaximumDistance(max_distance)
         euv.SetAlgorithmToSaito()
         euv.Update()
         return Volume(euv.GetOutput())
 
-    def correlationWith(self, vol2, dim=2):
+    def correlation_with(self, vol2, dim=2):
         """
         Find the correlation between two volumetric data sets.
         Keyword `dim` determines whether the correlation will be 3D, 2D or 1D.
@@ -694,6 +672,14 @@ class BaseVolume:
         imc.Update()
         return Volume(imc.GetOutput())
 
+    def scale_voxels(self, scale=1):
+        """Scale the voxel content by factor `scale`."""
+        rsl = vtk.vtkImageReslice()
+        rsl.SetInputData(self.imagedata())
+        rsl.SetScalarScale(scale)
+        rsl.Update()
+        return self._update(rsl.GetOutput())
+
 
 ##########################################################################
 class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
@@ -710,7 +696,7 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
     alphas : float, list
          sets transparencies along the scalar range
 
-    alphaUnit : float
+    alpha_unit : float
         low values make composite rendering look brighter and denser
 
     origin : list
@@ -784,8 +770,8 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
         inputobj=None,
         c="RdBu_r",
         alpha=(0.0, 0.0, 0.2, 0.4, 0.8, 1.0),
-        alphaGradient=None,
-        alphaUnit=1,
+        alpha_gradient=None,
+        alpha_unit=1,
         mode=0,
         spacing=None,
         dims=None,
@@ -831,7 +817,7 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
         if inputobj is None:
             img = vtk.vtkImageData()
 
-        elif utils.isSequence(inputobj):
+        elif utils.is_sequence(inputobj):
 
             if isinstance(inputobj[0], str) and ".bmp" in inputobj[0].lower():
                 # scan sequence of BMP files
@@ -909,17 +895,17 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
 
         if img.GetPointData().GetScalars():
             if img.GetPointData().GetScalars().GetNumberOfComponents() == 1:
-                self.mode(mode).color(c).alpha(alpha).alphaGradient(alphaGradient)
+                self.mode(mode).color(c).alpha(alpha).alpha_gradient(alpha_gradient)
                 self.GetProperty().SetShade(True)
                 self.GetProperty().SetInterpolationType(1)
-                self.GetProperty().SetScalarOpacityUnitDistance(alphaUnit)
+                self.GetProperty().SetScalarOpacityUnitDistance(alpha_unit)
 
         # remember stuff:
         self._mode = mode
         self._color = c
         self._alpha = alpha
-        self._alphaGrad = alphaGradient
-        self._alphaUnit = alphaUnit
+        self._alpha_grad = alpha_gradient
+        self._alpha_unit = alpha_unit
 
     def _update(self, data):
         self._data = data
@@ -1065,7 +1051,7 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
             vedo.logger.error("volume.mask() must create the volume with Volume(..., mapper='gpu')")
         return self
 
-    def alphaGradient(self, alphaGrad, vmin=None, vmax=None):
+    def alpha_gradient(self, alpha_grad, vmin=None, vmax=None):
         """
         Assign a set of tranparencies to a volume's gradient
         along the range of the scalar value.
@@ -1075,46 +1061,47 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
         at the boundaries between material types.  The gradient is measured
         as the amount by which the intensity changes over unit distance.
 
-        The format for alphaGrad is the same as for method `volume.alpha()`.
+        The format for alpha_grad is the same as for method `volume.alpha()`.
         """
         if vmin is None:
             vmin, _ = self._data.GetScalarRange()
         if vmax is None:
             _, vmax = self._data.GetScalarRange()
-        self._alphaGrad = alphaGrad
+        self._alpha_grad = alpha_grad
         volumeProperty = self.GetProperty()
-        if alphaGrad is None:
+
+        if alpha_grad is None:
             volumeProperty.DisableGradientOpacityOn()
             return self
-        else:
-            volumeProperty.DisableGradientOpacityOff()
+
+        volumeProperty.DisableGradientOpacityOff()
 
         gotf = volumeProperty.GetGradientOpacity()
-        if utils.isSequence(alphaGrad):
-            alphaGrad = np.array(alphaGrad)
-            if len(alphaGrad.shape)==1: # user passing a flat list e.g. (0.0, 0.3, 0.9, 1)
-                for i, al in enumerate(alphaGrad):
-                    xalpha = vmin + (vmax - vmin) * i / (len(alphaGrad) - 1)
+        if utils.is_sequence(alpha_grad):
+            alpha_grad = np.array(alpha_grad)
+            if len(alpha_grad.shape)==1: # user passing a flat list e.g. (0.0, 0.3, 0.9, 1)
+                for i, al in enumerate(alpha_grad):
+                    xalpha = vmin + (vmax - vmin) * i / (len(alpha_grad) - 1)
                     # Create transfer mapping scalar value to gradient opacity
                     gotf.AddPoint(xalpha, al)
-            elif len(alphaGrad.shape) == 2:  # user passing [(x0,alpha0), ...]
-                gotf.AddPoint(vmin, alphaGrad[0][1])
-                for xalpha, al in alphaGrad:
+            elif len(alpha_grad.shape) == 2:  # user passing [(x0,alpha0), ...]
+                gotf.AddPoint(vmin, alpha_grad[0][1])
+                for xalpha, al in alpha_grad:
                     # Create transfer mapping scalar value to opacity
                     gotf.AddPoint(xalpha, al)
-                gotf.AddPoint(vmax, alphaGrad[-1][1])
-            # print("alphaGrad at", round(xalpha, 1), "\tset to", al)
+                gotf.AddPoint(vmax, alpha_grad[-1][1])
+            # print("alpha_grad at", round(xalpha, 1), "\tset to", al)
         else:
-            gotf.AddPoint(vmin, alphaGrad)  # constant alphaGrad
-            gotf.AddPoint(vmax, alphaGrad)
+            gotf.AddPoint(vmin, alpha_grad)  # constant alpha_grad
+            gotf.AddPoint(vmax, alpha_grad)
         return self
 
-    def componentWeight(self, i, weight):
+    def component_weight(self, i, weight):
         """Set the scalar component weight in range [0,1]."""
         self.GetProperty().SetComponentWeight(i, weight)
         return self
 
-    def xSlice(self, i):
+    def xslice(self, i):
         """Extract the slice at index `i` of volume along x-axis."""
         vslice = vtk.vtkImageDataGeometryFilter()
         vslice.SetInputData(self.imagedata())
@@ -1125,7 +1112,7 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
         vslice.Update()
         return Mesh(vslice.GetOutput())
 
-    def ySlice(self, j):
+    def yslice(self, j):
         """Extract the slice at index `j` of volume along y-axis."""
         vslice = vtk.vtkImageDataGeometryFilter()
         vslice.SetInputData(self.imagedata())
@@ -1136,7 +1123,7 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
         vslice.Update()
         return Mesh(vslice.GetOutput())
 
-    def zSlice(self, k):
+    def zslice(self, k):
         """Extract the slice at index `i` of volume along z-axis."""
         vslice = vtk.vtkImageDataGeometryFilter()
         vslice.SetInputData(self.imagedata())
@@ -1147,7 +1134,12 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
         vslice.Update()
         return Mesh(vslice.GetOutput())
 
-    def slicePlane(self, origin=(0, 0, 0), normal=(1, 1, 1), autocrop=False):
+    @deprecated(reason=vedo.colors.red + "Please use slice_plane()" + vedo.colors.reset)
+    def slicePlane(self, *a, **b):
+        "Deprecated. Please use scalar_range()"
+        return self.slice_plane(*a, **b)
+
+    def slice_plane(self, origin=(0, 0, 0), normal=(1, 1, 1), autocrop=False):
         """
         Extract the slice along a given plane position and normal.
 
@@ -1179,6 +1171,119 @@ class Volume(vtk.vtkVolume, BaseGrid, BaseVolume):
         msh.SetPosition(pos)
         return msh
 
+    def warp(self, source, target, sigma=1, mode="3d", fit=False):
+        """
+        Warp volume scalars within a Volume by specifying source and target sets of points.
+
+        Parameters
+        ----------
+        source : Points, list
+            the list of source points
+
+        target : Points, list
+            the list of target points
+
+        fit : bool
+            fit/adapt the old bounding box to the warped geometry
+        """
+        if isinstance(source, vedo.Points):
+            source = source.points()
+        if isinstance(target, vedo.Points):
+            target = target.points()
+
+        ns = len(source)
+        ptsou = vtk.vtkPoints()
+        ptsou.SetNumberOfPoints(ns)
+        for i in range(ns):
+            ptsou.SetPoint(i, source[i])
+
+        nt = len(target)
+        if ns != nt:
+            vedo.logger.error(f"#source {ns} != {nt} #target points")
+            raise RuntimeError()
+
+        pttar = vtk.vtkPoints()
+        pttar.SetNumberOfPoints(nt)
+        for i in range(ns):
+            pttar.SetPoint(i, target[i])
+
+        T = vtk.vtkThinPlateSplineTransform()
+        if mode.lower() == "3d":
+            T.SetBasisToR()
+        elif mode.lower() == "2d":
+            T.SetBasisToR2LogR()
+        else:
+            vedo.logger.error(f"unknown mode {mode}")
+            raise RuntimeError()
+
+        T.SetSigma(sigma)
+        T.SetSourceLandmarks(ptsou)
+        T.SetTargetLandmarks(pttar)
+        T.Inverse()
+        self.transform = T
+        self.apply_transform(T, fit=fit)
+        return self
+
+    def apply_transform(self, T, fit=False):
+        """
+        Apply a VTK transform to the scalars in the volume.
+
+        Parameters
+        ----------
+        T : vtkTransform, matrix
+            The transformation to be applied
+
+        fit : bool
+            fit/adapt the old bounding box to the warped geometry
+        """
+        if isinstance(T, vtk.vtkMatrix4x4):
+            tr = vtk.vtkTransform()
+            tr.SetMatrix(T)
+            T = tr
+
+        elif utils.is_sequence(T):
+            M = vtk.vtkMatrix4x4()
+            n = len(T[0])
+            for i in range(n):
+                for j in range(n):
+                    M.SetElement(i, j, T[i][j])
+            tr = vtk.vtkTransform()
+            tr.SetMatrix(M)
+            T = tr
+
+        reslice = vtk.vtkImageReslice()
+        reslice.SetInputData(self._data)
+        reslice.SetResliceTransform(T)
+        reslice.SetOutputDimensionality(3)
+        reslice.SetInterpolationModeToLinear()
+
+        spacing = self._data.GetSpacing()
+        origin = self._data.GetOrigin()
+
+        if fit:
+            bb = self.box()
+            if isinstance(T, vtk.vtkThinPlateSplineTransform):
+                TI = vtk.vtkThinPlateSplineTransform()
+                TI.DeepCopy(T)
+                TI.Inverse()
+            else:
+                TI = vtk.vtkTransform()
+                TI.DeepCopy(T)
+            bb.apply_transform(TI)
+            bounds = bb.GetBounds()
+            bounds = (
+                bounds[0]/spacing[0], bounds[1]/spacing[0],
+                bounds[2]/spacing[1], bounds[3]/spacing[1],
+                bounds[4]/spacing[2], bounds[5]/spacing[2],
+            )
+            bounds = np.round(bounds).astype(int)
+            reslice.SetOutputExtent(bounds)
+            reslice.SetOutputSpacing(spacing[0], spacing[1], spacing[2])
+            reslice.SetOutputOrigin(origin[0], origin[1], origin[2])
+
+        reslice.Update()
+        return self._update(reslice.GetOutput())
+
 
 ##########################################################################
 class VolumeSlice(vtk.vtkImageSlice, Base3DProp, BaseVolume):
@@ -1226,7 +1331,7 @@ class VolumeSlice(vtk.vtkImageSlice, Base3DProp, BaseVolume):
             img = inputobj.imagedata()
             self.lut = utils.ctf2lut(inputobj)
 
-        elif utils.isSequence(inputobj):
+        elif utils.is_sequence(inputobj):
 
             if isinstance(inputobj[0], str):  # scan sequence of BMP files
                 ima = vtk.vtkImageAppend()
@@ -1295,10 +1400,10 @@ class VolumeSlice(vtk.vtkImageSlice, Base3DProp, BaseVolume):
         self.GetBounds(bns)
         return bns
 
-    def colorize(self, lut=None, fixScalarRange=False):
+    def colorize(self, lut=None, fix_scalar_range=False):
         """
         Assign a LUT (Look Up Table) to colorize the slice, leave it ``None``
-        to reuse an exisiting Volume color map.
+        to reuse an existing Volume color map.
         Use "bw" for automatic black and white.
         """
         if lut is None and self.lut:
@@ -1307,7 +1412,7 @@ class VolumeSlice(vtk.vtkImageSlice, Base3DProp, BaseVolume):
             self.property.SetLookupTable(lut)
         elif lut == "bw":
             self.property.SetLookupTable(None)
-        self.property.SetUseLookupTableScalarRange(fixScalarRange)
+        self.property.SetUseLookupTableScalarRange(fix_scalar_range)
         return self
 
     def alpha(self, value):
@@ -1315,12 +1420,12 @@ class VolumeSlice(vtk.vtkImageSlice, Base3DProp, BaseVolume):
         self.property.SetOpacity(value)
         return self
 
-    def autoAdjustQuality(self, value=True):
+    def auto_adjust_quality(self, value=True):
         """Automatically reduce the rendering quality for greater speed when interacting"""
         self._mapper.SetAutoAdjustImageQuality(value)
         return self
 
-    def slab(self, thickness=0, mode=0, sampleFactor=2):
+    def slab(self, thickness=0, mode=0, sample_factor=2):
         """
         Make a thick slice (slab).
 
@@ -1336,29 +1441,29 @@ class VolumeSlice(vtk.vtkImageSlice, Base3DProp, BaseVolume):
             2 = mean
             3 = sum
 
-        sampleFactor : float
+        sample_factor : float
             Set the number of slab samples to use as a factor of the number of input slices
             within the slab thickness. The default value is 2, but 1 will increase speed
             with very little loss of quality.
         """
         self._mapper.SetSlabThickness(thickness)
         self._mapper.SetSlabType(mode)
-        self._mapper.SetSlabSampleFactor(sampleFactor)
+        self._mapper.SetSlabSampleFactor(sample_factor)
         return self
 
-    def faceCamera(self, value=True):
+    def face_camera(self, value=True):
         """Make the slice always face the camera or not."""
         self._mapper.SetSliceFacesCameraOn(value)
         return self
 
-    def jumpToNearestSlice(self, value=True):
+    def jump_to_nearest_slice(self, value=True):
         """This causes the slicing to occur at the closest slice to the focal point,
         instead of the default behavior where a new slice is interpolated between the original slices.
         Nothing happens if the plane is oblique to the original slices."""
         self.SetJumpToNearestSlice(value)
         return self
 
-    def fillBackground(self, value=True):
+    def fill_background(self, value=True):
         """Instead of rendering only to the image border, render out to the viewport boundary with
         the background color. The background color will be the lowest color on the lookup
         table that is being used for the image."""
